summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h')
-rw-r--r--kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
index 540d774d..fd65c39c 100644
--- a/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
+++ b/kopete/protocols/jabber/jingle/libjingle/talk/xmpp/xmppclient.h
@@ -51,9 +51,9 @@ class CaptchaChallenge;
//
/////////////////////////////////////////////////////////////////////
//
// See Task first. XmppClient is a tqparent task for XmppTasks.
//
// XmppClient is a task which is designed to be the tqparent task for
// all tasks that depend on a single Xmpp connection. If you want to,
// for example, listen for subscription requests forever, then your
// listener should be a task that is a child of the XmppClient that owns
@@ -71,7 +71,7 @@ class CaptchaChallenge;
class XmppClient : public Task, public sigslot::has_slots<>
{
public:
- XmppClient(Task * tqparent);
+ XmppClient(Task * parent);
~XmppClient();
XmppReturntqStatus Connect(const XmppClientSettings & settings,
@@ -51,9 +51,9 @@ class CaptchaChallenge;
/////////////////////////////////////////////////////////////////////
//
-// See Task first. XmppClient is a tqparent task for XmppTasks.
+// See Task first. XmppClient is a parent task for XmppTasks.
//
@@ -51,9 +51,9 @@ class CaptchaChallenge;
//
-// XmppClient is a task which is designed to be the tqparent task for
+// XmppClient is a task which is designed to be the parent task for
// all tasks that depend on a single Xmpp connection. If you want to,
// for example, listen for subscription requests forever, then your